@@ -1,6 +1,6 @@
 package Sparrow;
 
-our $VERSION = '0.2.36';
+our $VERSION = '0.2.37';
 
 1;
 
@@ -1051,12 +1051,13 @@ push your changes into remote git repository
 
 This is the way how one can declare dependencies for sparrow plugins:
 
-    +----------+----------+
-    | Language |  File    |
-    +----------+----------+
-    | Perl     | cpanfile |
-    | Ruby     | Gemfile  |
-    +----------+----------+
+    +----------+-------------------+
+    | Language |  File             |
+    +----------+-------------------+
+    | Perl     | cpanfile          |
+    | Ruby     | Gemfile           |
+    | Python   | requirements.txt  |
+    +----------+-------------------+
 
 You should place a dependency file into a plugin root directory.
 
@@ -1130,7 +1131,7 @@ Pretty cool, huh? :)))
 
 A shortcut for C<sparrow remote task install ... & sparrow task run> is:
 
-    $ sparrow remote task task run utils/git-setup
+    $ sparrow remote task run utils/git-setup
 
 
 =head2 Share your task
